@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2004, 2005, 2006, 2007  Free Software Foundation, Inc.
+ * Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation, Inc.
  *
  * Author: Oliver Hitz
  *
@@ -330,8 +330,14 @@ public class GenerateNFKC
     // Dump combining classes
     {
       PrintWriter w = new PrintWriter(new FileWriter("CombiningClass.java"));
-      w.println("/* Do not edit - automatically generated */");
+      w.println("/* This file is automatically generated.  DO NOT EDIT!");
+      w.println("   Instead, edit GenerateNFKC.java and re-run.  */");
       w.println();
+      w.println("package gnu.inet.encoding;");
+      w.println();
+      w.println("/**");
+      w.println(" * Auto-generated class containing Unicode NFKC tables.");
+      w.println(" */");
       w.println("public class CombiningClass");
       w.println("{");
       w.println("  public final static int[][] c = new int[][] {");
@@ -386,8 +392,14 @@ public class GenerateNFKC
     // Dump compatibility decomposition
     {
       PrintWriter w = new PrintWriter(new FileWriter("DecompositionKeys.java"));
-      w.println("/* Do not edit - automatically generated */");
+      w.println("/* This file is automatically generated.  DO NOT EDIT!");
+      w.println("   Instead, edit GenerateNFKC.java and re-run.  */");
       w.println();
+      w.println("package gnu.inet.encoding;");
+      w.println();
+      w.println("/**");
+      w.println(" * Auto-generated class containing Unicode NFKC tables.");
+      w.println(" */");
       w.println("public class DecompositionKeys");
       w.println("{");
       w.println("  public final static int[] k = new int[] {");
@@ -407,8 +419,14 @@ public class GenerateNFKC
     
     {
       PrintWriter w = new PrintWriter(new FileWriter("DecompositionMappings.java"));
-      w.println("/* Do not edit - automatically generated */");
+      w.println("/* This file is automatically generated.  DO NOT EDIT!");
+      w.println("   Instead, edit GenerateNFKC.java and re-run.  */");
       w.println();
+      w.println("package gnu.inet.encoding;");
+      w.println();
+      w.println("/**");
+      w.println(" * Auto-generated class containing Unicode NFKC tables.");
+      w.println(" */");
       w.println("public class DecompositionMappings");
       w.println("{");
       w.println("  public final static String[] m = new String[] {");
@@ -428,8 +446,14 @@ public class GenerateNFKC
     // Dump canonical composition
     {
       PrintWriter w = new PrintWriter(new FileWriter("Composition.java"));
-      w.println("/* Do not edit - automatically generated */");
+      w.println("/* This file is automatically generated.  DO NOT EDIT!");
+      w.println("   Instead, edit GenerateNFKC.java and re-run.  */");
       w.println();
+      w.println("package gnu.inet.encoding;");
+      w.println();
+      w.println("/**");
+      w.println(" * Auto-generated class containing Unicode NFKC tables.");
+      w.println(" */");
       w.println("public class Composition");
       w.println("{");
 
