@@ -1,5 +1,5 @@
 /* nfkc.c --- Unicode normalization utilities.
- * Copyright (C) 2002, 2003, 2004, 2006, 2007  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2009  Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -50,8 +50,8 @@
 #define gssize ssize_t
 #define g_malloc malloc
 #define g_free free
-#define GError void
-#define g_set_error(a,b,c,d) ((void) 0)
+#define GError void*
+#define g_set_error(a,b,c,d) (a = NULL)
 #define g_new(struct_type, n_structs)					\
   ((struct_type *) g_malloc (((gsize) sizeof (struct_type)) * ((gsize) (n_structs))))
 #  if defined (__GNUC__) && !defined (__STRICT_ANSI__) && !defined (__cplusplus)
@@ -143,13 +143,6 @@ GNormalizeMode;
       (Result) |= ((Chars)[(Count)] & 0x3f);		\
     }
 
-#define UNICODE_VALID(Char)			\
-  ((Char) < 0x110000 &&				\
-   (((Char) & 0xFFFFF800) != 0xD800) &&		\
-   ((Char) < 0xFDD0 || (Char) > 0xFDEF) &&	\
-   ((Char) & 0xFFFE) != 0xFFFE)
-
-
 static const gchar utf8_skip_data[256] = {
   1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
   1, 1, 1, 1, 1, 1, 1,
@@ -171,7 +164,7 @@ static const gchar utf8_skip_data[256] = {
 
 static const gchar *const g_utf8_skip = utf8_skip_data;
 
-#define g_utf8_next_char(p) (char *)((p) + g_utf8_skip[*(guchar *)(p)])
+#define g_utf8_next_char(p) ((p) + g_utf8_skip[*(const guchar *)(p)])
 
 /*
  * g_utf8_strlen:
@@ -266,7 +259,6 @@ g_unichar_to_utf8 (gunichar c, gchar * outbuf)
 {
   guint len = 0;
   int first;
-  int i;
 
   if (c < 0x80)
     {
@@ -301,6 +293,7 @@ g_unichar_to_utf8 (gunichar c, gchar * outbuf)
 
   if (outbuf)
     {
+      guint i;
       for (i = len - 1; i > 0; --i)
 	{
 	  outbuf[i] = (c & 0x3f) | 0x80;
@@ -364,7 +357,7 @@ g_utf8_to_ucs4_fast (const gchar * str, glong len, glong * items_written)
   p = str;
   for (i = 0; i < n_chars; i++)
     {
-      gunichar wc = ((unsigned char *) p)[0];
+      gunichar wc = ((const unsigned char *) p)[0];
 
       if (wc < 0x80)
 	{
@@ -402,7 +395,7 @@ g_utf8_to_ucs4_fast (const gchar * str, glong len, glong * items_written)
 	  for (j = 1; j < charlen; j++)
 	    {
 	      wc <<= 6;
-	      wc |= ((unsigned char *) p)[j] & 0x3f;
+	      wc |= ((const unsigned char *) p)[j] & 0x3f;
 	    }
 
 	  result[i] = wc;
