@@ -1,5 +1,5 @@
 /* idn.c --- Command line interface to libidn.
- * Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008  Simon Josefsson
+ * Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009  Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -46,7 +46,7 @@
 #include "idn_cmd.h"
 
 #define GREETING \
-  "Copyright 2002, 2003, 2004, 2005, 2006, 2007, 2008 Simon Josefsson.\n" \
+  "Copyright 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Simon Josefsson.\n" \
   "GNU Libidn comes with NO WARRANTY, to the extent permitted by law.\n" \
   "You may redistribute copies of GNU Libidn under the terms of\n"	\
   "the GNU Lesser General Public License.  For more information\n"	\
@@ -66,6 +66,9 @@ emit_bug_reporting_address (void)
      "Report translation bugs to <...>\n" with the address for translation
      bugs (typically your translation team's web or email address).  */
   printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
+  printf (_("%s home page: http://www.gnu.org/software/%s/\n"),
+	  PACKAGE_NAME, PACKAGE);
+  printf (_("General help using GNU software: http://www.gnu.org/gethelp/\n"));
 }
 
 static void
@@ -107,11 +110,11 @@ Mandatory arguments to long options are mandatory for short options too.\n\
   -u, --idna-to-unicode    Convert from ACE according to IDNA\n\
 "), stdout);
       fputs (_("\
-      --allow-unassigned   Toggle IDNA AllowUnassigned flag\n\
-      --usestd3asciirules  Toggle IDNA UseSTD3ASCIIRules flag\n\
+      --allow-unassigned   Toggle IDNA AllowUnassigned flag (default off)\n\
+      --usestd3asciirules  Toggle IDNA UseSTD3ASCIIRules flag (default off)\n\
 "), stdout);
       fputs (_("\
-  -t, --tld                Check string for TLD specific rules\n\
+      --no-tld             Don't check string for TLD specific rules\n\
                              Only for --idna-to-ascii and --idna-to-unicode\n\
 "), stdout);
       fputs (_("\
@@ -388,7 +391,7 @@ main (int argc, char *argv[])
 		   idna_strerror (rc));
 
 #ifdef WITH_TLD
-	  if (args_info.tld_flag)
+	  if (args_info.tld_flag && !args_info.no_tld_flag)
 	    {
 	      size_t errpos;
 
