@@ -1,5 +1,5 @@
 /* utils.h --- Prototypes for self test utilities.
- * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -25,11 +25,18 @@
 # include <stdarg.h>
 # include <stringprep.h>
 
+#ifndef __attribute__
+# if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 5)
+#  define __attribute__(Spec)	/* empty */
+# endif
+#endif
+
 extern int debug;
 extern int error_count;
 extern int break_on_error;
 
-extern void fail (const char *format, ...);
+extern void fail (const char *format, ...)
+  __attribute__ ((format (printf, 1, 2)));
 extern void escapeprint (const char *str, size_t len);
 extern void hexprint (const char *str, size_t len);
 extern void binprint (const char *str, size_t len);
